/*
 * aero.c - general purpose aero functions for ducted fan
 *
 * RMM, 19 May 96
 *
 */

#include <stdio.h>
#include "aero.h"

/* Global variables */
int aero_verbose = 0;			/* for printing messages */

/*******************************************************/
int compute_alphaVgamma(double thetarad, double xdot, double zdot, double *alphaVgam)
/* 
 * compute angle of attack alpha [rad],  windspeed Vel [m/s] 
 * and flight path angle gammarad [rad] from state
 *
 * |alpha| < PI always.
 */
/*******************************************************/
{
    double gammarad, alpharad, Vel;
    
    if(xdot<0.0) {
	/* flip to 1-4 quadrant */
	xdot = -xdot; 
	zdot = -zdot;
	thetarad = thetarad-M_PI;
    }
    
    Vel = sqrt(xdot*xdot + zdot*zdot);  /* velocity */
    if (fabs(Vel) < .000001)
	{
	    gammarad = 0.0;
	    alpharad = 0.0;
	}
    else
	{
	    gammarad = -atan2(zdot, xdot);       /* flight path angle */
	    alpharad = thetarad - gammarad;     /* angle of attack */
	    
	    while(alpharad > (2.0*M_PI)) alpharad -= (2.0*M_PI);
	    while(alpharad <-(2.0*M_PI)) alpharad += (2.0*M_PI);
	}
    
    alphaVgam[0] = alpharad; 
    alphaVgam[1] = Vel;
    alphaVgam[2] = gammarad;
    
    return 1;
} /*** end compute_alphaVgamma() ***/



