function [ret,x0,str,ts,xts]=demosurf(t,x,u,flag);
%DEMOSURF	is the M-file description of the SIMULINK system named DEMOSURF.
%	DEMOSURF has a the following characteristics:
%		7 continuous states
%		36 discrete states
%		0 outputs
%		0 inputs
%		does not have direct feedthrough
%		1 sample times
%
%	The block-diagram can be displayed by typing: DEMOSURF.
%
%	SYS=DEMOSURF(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEMOSURF to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEMOSURF with a FLAG of zero:
%	[SIZES]=DEMOSURF([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[8,117,679,417])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '250')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/S-Function',[sys,'/','Ducted Fan'])
set_param([sys,'/','Ducted Fan'],...
		'function name','fansim',...
		'parameters','state',...
		'position',[450,95,525,115])


%     Subsystem  'Controller'.

new_system([sys,'/','Controller'])
set_param([sys,'/','Controller'],'Location',[192,507,594,686])

add_block('built-in/Outport',[sys,'/','Controller/u'])
set_param([sys,'/','Controller/u'],...
		'position',[295,70,315,90])

add_block('built-in/State-Space',[sys,'/','Controller/Controller'])
set_param([sys,'/','Controller/Controller'],...
		'A','Ac',...
		'B','Bc',...
		'C','Cc',...
		'D','Dc',...
		'position',[185,59,260,101])

add_block('built-in/Inport',[sys,'/','Controller/x_d'])
set_param([sys,'/','Controller/x_d'],...
		'Port','2',...
		'position',[80,75,100,95])

add_block('built-in/Inport',[sys,'/','Controller/x'])
set_param([sys,'/','Controller/x'],...
		'move name',0,...
		'position',[80,60,100,80])

add_block('built-in/Mux',[sys,'/','Controller/Mux1'])
set_param([sys,'/','Controller/Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[130,61,160,94])
add_line([sys,'/','Controller'],[105,70;125,70])
add_line([sys,'/','Controller'],[265,80;290,80])
add_line([sys,'/','Controller'],[105,85;125,85])
add_line([sys,'/','Controller'],[165,80;180,80])


%     Finished composite block 'Controller'.

set_param([sys,'/','Controller'],...
		'position',[210,67,240,118])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[285,80,305,100])


%     Subsystem  'display'.

new_system([sys,'/','display'])
set_param([sys,'/','display'],'Location',[659,417,1145,843])
open_system([sys,'/','display'])

add_block('built-in/Inport',[sys,'/','display/in_1'])
set_param([sys,'/','display/in_1'],...
		'position',[30,95,50,115])

add_block('built-in/Demux',[sys,'/','display/xd//ud'])
set_param([sys,'/','display/xd//ud'],...
		'outputs','6',...
		'position',[75,69,110,141])

add_block('built-in/Mux',[sys,'/','display/Mux2'])
set_param([sys,'/','display/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[145,105,175,175])


%     Subsystem  'display/x, z, theta'.

new_system([sys,'/','display/x, z, theta'])
set_param([sys,'/','display/x, z, theta'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','display/x, z, theta/x'])
set_param([sys,'/','display/x, z, theta/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['display/x, z, theta/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/x, z, theta/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','display/x, z, theta'],[90,65;125,65])
set_param([sys,'/','display/x, z, theta'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-./w:/m/ro''\/')


%     Finished composite block 'display/x, z, theta'.

set_param([sys,'/','display/x, z, theta'],...
		'position',[205,40,235,80])

add_block('built-in/Mux',[sys,'/','display/Mux1'])
set_param([sys,'/','display/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[150,24,175,96])


%     Subsystem  'display/xdot, zdot, thetadot'.

new_system([sys,'/','display/xdot, zdot, thetadot'])
set_param([sys,'/','display/xdot, zdot, thetadot'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['display/xdot, zdot, thetadot/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/xdot, zdot, thetadot/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','display/xdot, zdot, thetadot/x'])
set_param([sys,'/','display/xdot, zdot, thetadot/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','display/xdot, zdot, thetadot'],[90,65;125,65])
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-./w:/m/ro''\/')


%     Finished composite block 'display/xdot, zdot, thetadot'.

set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'position',[225,140,255,180])

add_block('built-in/Note',[sys,'/',['display/Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']])
set_param([sys,'/',['display/Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']],...
		'position',[175,370,180,375])


%     Subsystem  'display/reference trajectory'.

new_system([sys,'/','display/reference trajectory'])
set_param([sys,'/','display/reference trajectory'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','display/reference trajectory/x'])
set_param([sys,'/','display/reference trajectory/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['display/reference trajectory/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/reference trajectory/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','display/reference trajectory'],[90,65;125,65])
set_param([sys,'/','display/reference trajectory'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/c-./w:/m*/ro''\/')


%     Finished composite block 'display/reference trajectory'.

set_param([sys,'/','display/reference trajectory'],...
		'position',[115,285,145,325])

add_block('built-in/Inport',[sys,'/','display/in_4'])
set_param([sys,'/','display/in_4'],...
		'Port','3',...
		'position',[30,295,50,315])

add_block('built-in/Inport',[sys,'/','display/in_3'])
set_param([sys,'/','display/in_3'],...
		'Port','2',...
		'position',[25,225,45,245])


%     Subsystem  'display/Fxbody, Fzbody, deltae'.

new_system([sys,'/','display/Fxbody, Fzbody, deltae'])
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['display/Fxbody, Fzbody, deltae/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/Fxbody, Fzbody, deltae/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','display/Fxbody, Fzbody, deltae/x'])
set_param([sys,'/','display/Fxbody, Fzbody, deltae/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','display/Fxbody, Fzbody, deltae'],[90,65;125,65])
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-.''\/')


%     Finished composite block 'display/Fxbody, Fzbody, deltae'.

set_param([sys,'/','display/Fxbody, Fzbody, deltae'],...
		'position',[105,215,135,255])
add_line([sys,'/','display'],[55,305;110,305])
add_line([sys,'/','display'],[50,235;100,235])
add_line([sys,'/','display'],[55,105;70,105])
add_line([sys,'/','display'],[115,90;120,90;120,60;145,60])
add_line([sys,'/','display'],[115,100;120,100;120,85;145,85])
add_line([sys,'/','display'],[180,60;200,60])
add_line([sys,'/','display'],[115,110;120,110;120,115;140,115])
add_line([sys,'/','display'],[115,120;120,120;120,140;140,140])
add_line([sys,'/','display'],[115,130;120,130;120,165;140,165])
add_line([sys,'/','display'],[180,140;220,160])


%     Finished composite block 'display'.

set_param([sys,'/','display'],...
		'position',[565,80,615,240])


%     Subsystem  'Surface Allocation'.

new_system([sys,'/','Surface Allocation'])
set_param([sys,'/','Surface Allocation'],'Location',[449,507,736,655])

add_block('built-in/S-Function',[sys,'/','Surface Allocation/Surface Allocation'])
set_param([sys,'/','Surface Allocation/Surface Allocation'],...
		'function name','surfalloc',...
		'position',[125,55,185,75])

add_block('built-in/Mux',[sys,'/','Surface Allocation/Mux'])
set_param([sys,'/','Surface Allocation/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[50,46,80,79])

add_block('built-in/Inport',[sys,'/','Surface Allocation/u'])
set_param([sys,'/','Surface Allocation/u'],...
		'move name',0,...
		'position',[15,45,35,65])

add_block('built-in/Outport',[sys,'/','Surface Allocation/out_1'])
set_param([sys,'/','Surface Allocation/out_1'],...
		'hide name',0,...
		'position',[210,55,230,75])

add_block('built-in/Inport',[sys,'/','Surface Allocation/x'])
set_param([sys,'/','Surface Allocation/x'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Surface Allocation'],[85,65;120,65])
add_line([sys,'/','Surface Allocation'],[40,55;45,55])
add_line([sys,'/','Surface Allocation'],[190,65;205,65])
add_line([sys,'/','Surface Allocation'],[40,70;45,70])


%     Finished composite block 'Surface Allocation'.

set_param([sys,'/','Surface Allocation'],...
		'position',[365,77,395,128])


%     Subsystem  'Trajectory Generation'.

new_system([sys,'/','Trajectory Generation'])
set_param([sys,'/','Trajectory Generation'],'Location',[8,414,392,609])

add_block('built-in/Outport',[sys,'/','Trajectory Generation/x_d'])
set_param([sys,'/','Trajectory Generation/x_d'],...
		'Port','2',...
		'position',[330,90,350,110])

add_block('built-in/Outport',[sys,'/','Trajectory Generation/u_d'])
set_param([sys,'/','Trajectory Generation/u_d'],...
		'move name',0,...
		'position',[330,75,350,95])

add_block('built-in/Mux',[sys,'/','Trajectory Generation/Mux1'])
set_param([sys,'/','Trajectory Generation/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[245,28,275,62])

add_block('built-in/Mux',[sys,'/','Trajectory Generation/Mux2'])
set_param([sys,'/','Trajectory Generation/Mux2'],...
		'hide name',0,...
		'inputs','6',...
		'position',[245,81,275,114])

add_block('built-in/Demux',[sys,'/','Trajectory Generation/xd//ud'])
set_param([sys,'/','Trajectory Generation/xd//ud'],...
		'outputs','9',...
		'position',[160,69,200,111])

add_block('built-in/Inport',[sys,'/','Trajectory Generation/in_1'])
set_param([sys,'/','Trajectory Generation/in_1'],...
		'hide name',0,...
		'position',[15,80,35,100])

add_block('built-in/S-Function',[sys,'/','Trajectory Generation/Reference Trajectory'])
set_param([sys,'/','Trajectory Generation/Reference Trajectory'],...
		'function name','trjfile',...
		'parameters','''milam-may96/forward.trj''',...
		'position',[65,80,115,100])
add_line([sys,'/','Trajectory Generation'],[120,90;155,90])
add_line([sys,'/','Trajectory Generation'],[40,90;60,90])
add_line([sys,'/','Trajectory Generation'],[205,70;220,70;220,35;240,35])
add_line([sys,'/','Trajectory Generation'],[205,75;225,75;225,45;240,45])
add_line([sys,'/','Trajectory Generation'],[280,100;325,100])
add_line([sys,'/','Trajectory Generation'],[280,45;295,45;295,85;325,85])
add_line([sys,'/','Trajectory Generation'],[205,85;240,85])
add_line([sys,'/','Trajectory Generation'],[205,90;240,90])
add_line([sys,'/','Trajectory Generation'],[205,95;240,95])
add_line([sys,'/','Trajectory Generation'],[205,100;240,100])
add_line([sys,'/','Trajectory Generation'],[205,105;240,105])
add_line([sys,'/','Trajectory Generation'],[205,110;240,110])
add_line([sys,'/','Trajectory Generation'],[205,80;230,80;240,55])


%     Finished composite block 'Trajectory Generation'.

set_param([sys,'/','Trajectory Generation'],...
		'position',[85,67,115,118])

add_block('built-in/Note',[sys,'/',['Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']])
set_param([sys,'/',['Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']],...
		'position',[525,260,530,265])

add_block('built-in/Note',[sys,'/',['demosurf.m  .......... run initsurf.m first.',13,'Simulation for forward flight stabilization. ']])
set_param([sys,'/',['demosurf.m  .......... run initsurf.m first.',13,'Simulation for forward flight stabilization. ']],...
		'position',[155,235,160,240])
add_line(sys,[530,105;540,105;540,155;320,155;320,115;360,115])
add_line(sys,[530,105;540,105;540,60;190,60;190,80;205,80])
add_line(sys,[120,105;205,105])
add_line(sys,[120,80;170,80;170,40;260,40;260,85;280,85])
add_line(sys,[530,105;560,105])
add_line(sys,[245,95;280,95])
add_line(sys,[310,90;360,90])
add_line(sys,[400,105;445,105])
add_line(sys,[120,105;130,105;130,215;560,215])
add_line(sys,[310,90;310,169;560,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
