/*
 * dfspec.c - find a file in the dfan library
 *
 * dfspec() attempts to locate a file in the DFAN library.  The following
 * paths are considered (in order):
 *
 *      1. The current directory
 *      2. DFANLIB environment variable (list of paths)
 *      3. DFANLIB preprocessor variable (list of paths)
 *
 * dfspec() returns (through an argument) the full pathname specification.
 */

#include <stdio.h>
#include <sys/param.h>			/* for MAXPATHLEN */

/* Function declarations */
char *getenv(char *);
char *pathspec(char *, char *, char*);

#define PATH_DELIMIT ':'		/* delimiter in path variables */
#ifndef DFANLIB
#  define DFANLIB "/home/dfan/lib"	/* default library location */
#endif

/* Open an initialization file */
char *dfspec(file, spec)
char *file, *spec;
{
    FILE *fp;
    static char filespec[MAXPATHLEN];
    char *tmpstr;

    /* Start with the current directory */
    if ((fp = fopen(file, "r")) != NULL) {
	fclose(fp);
	if (spec != NULL) strcpy(spec, filespec);
	return file;
    }

    /* Check in DFAN library directory */
    if ((tmpstr = getenv("DFANLIB")) != NULL &&
	pathspec(tmpstr, file, filespec) != NULL) {
	if (spec != NULL) strcpy(spec, filespec);
	return filespec;
    }

    /* Hardwired path is next */
#   ifdef DFANLIB
    if (pathspec(DFANLIB, file, filespec) != NULL) {
	if (spec != NULL) strcpy(spec, filespec);
	return filespec;
    }
#   endif

    /* If we got here we have failed */
    return(NULL);
}

/* Open a file given a set of paths seperated by colons */
char *pathspec(path, file, filespec)
char *path, *file, *filespec;
{
    int pathlen, end;
    FILE *fp = NULL;

    if (path == NULL) return(NULL);
#   ifdef DEBUG
    printf("pathopen: path = %s, file = %s\n", path, file);
#   endif

    while (*path != '\0') {
	/* Find the end of the path */
	for (pathlen = 0; path[pathlen] != '\0' &&
			  path[pathlen] != PATH_DELIMIT; ++pathlen);

	/* Append the filename to the path name */
	(void) strncpy(filespec, path, pathlen);
	end = path[pathlen-1];

	/* Skip the delimiter */
	path += pathlen;
	if (*path != '\0') ++path;

	/* See if we need to add a seperator */
	if (end != '/' && end != '\\' && end != ']')
	    /* We *probably* need to add a delimiter for unix/msdos */
	    filespec[pathlen++] = '/';

	/* Copy the base name onto the path */
	strcpy(filespec+pathlen, file);
#	ifdef DEBUG
	printf("\tfilespec = %s\n", filespec);
#	endif

	/* Now try to open the file */
	if ((fp = fopen(filespec, "r")) != NULL) break;

	/* Go on to the next stop */
    }

    /* See if we actually found the file or not */
    if (fp != NULL) {
	/* Close up the file since we don't really care, the return filespec */
	fclose(fp);
	return filespec;
    }

    /* Didn't find the file */
    return NULL;
}

