%% initdemo.m
%initialization file for demo.m
%define various constants for Milam fan simulation
%
%dstate = fanrhs(time, state, input, FLAG)
%
%MvN 3/24/96, FB 5/13/96


disp(' initdemo.m');
disp(' + define some variables');

% useful params
rad2deg = 180/pi; RAD2DEG = 180/pi;
deg2rad = pi/180; DEG2RAD = pi/180;
FLAG = 1;
time = 0;

% various others
mx = 4.9; 
mz = 8.36; 
mg = 0.46; 
Jtheta = 0.0323; 
grav = 9.8066;   
Fzoffset = grav*mg; 
r = 0.12; 				% dist(c.m., point where forces attach) [m]
Ts = 0.005; 				% 200 Hz


%%%% define trim conditions:
xdot    = 6; 				%% m/s
Vm      = (1); 				%% volts
theta   = (12)*DEG2RAD; 		%% rad
delta_e = 4.95*DEG2RAD; 			%% rad
paddle  = 0*DEG2RAD; 			%% rad

%% (( a good set was [8m/s, 7deg, 1.825volt, -1.5delta_e,0] ))
%% Now, define x(t)=xdot*t
T=(0:.1:25)';
Xtime=(xdot*T); 			%% meters per second


%%% set up nominal state of fansim
state = [0 0 theta xdot 0 0]; 		%% state=[x,y,theta,xdot,ydot,thetadot]
input = [Vm paddle delta_e]; 		%% inputs=[Voltm,paddle,delta_e]

disturbance = [0 0 10*DEG2RAD 0 0 0];

% let's run milamfun once, to initialize the cmex file
% and to show how to call it:
dstate = fanrhs(time, state, input, FLAG)

% compute the linearization with linmod
% note c=eye and d=zero
[Af Bf Cf Df] = linmod('fanrhs', state, input, state);

% simple static lqr controller.
Q = diag([.1 20 10 .1 1 10]);
R = [1 0 0; 0 3 0; 0 0 3];

K = lqr(Af,Bf,Q,R);

%%% all the zeros are required to fit the [Ac, Bc, Cc, Dc]
%%% structure required in the simulink block "controller".
Ac = -1;
Bc = [0,0,0,0,0,0,0,0,0,0,0,0];
Cc = [0; 0; 0];
Dc = [0,0,0,0,0,0,0,0,0,0,0,0;
    0,0,0,0,0,0,0,0,0,0,0,0;
    0,0,0,0,0,0,0,0,0,0,0,0];

%% here we actually plug in the controller:
%% two copies of K mean (x-xd)
Dc = [K -K];


%% done


