#include <stdio.h>
#include "aero.h"

/* 
 * Surface allocation: 
 * various ways to go from generalized forces to motor voltage 
 * and paddle and elevator angles. 
 *
 * MvN 4/27/96. 
 * FB 5/19/96  loads new inverse table
 */

#include <stdlib.h>
#include "aero.h"
extern char *dfspec(char *, char *);

LU_DATA *forcetable = NULL; 

/***************************************************************/
int init_surfalloc()
/***************************************************************/
{  
  char filename[1024];
  
  if (dfspec(FORCE_TABLE, filename) == NULL ||
      (forcetable = lu_load(filename)) == NULL){
      printf("shroundinv: Error Loading %s !\n", FORCE_TABLE);
      exit(-1);
  }
  if (aero_verbose > 0) lu_dispinfo(forcetable);
  return 1;
}


/***************************************************************/
int force_to_voltflap(double *alphaVgamma, double *Fbody, double *Volt_paddle)
/* 
 * Surface allocation. 
 * alphaVgamma = alpha, Vel, gamma  .... [rad, Vel, rad]
 * Fbody = [Fxbody, Fzbody] [Newtons, Newtons]
 * Volt_paddle = *(Volt, paddle angle)  [V, rad]
 */
/***************************************************************/
{
    double table_in[4];
    register int i;
    
    /* from ~dfan/lib/milam-may96/README: 
     * table_in = (Vel, alphadeg, Fxbody, Fzbody)
     * unit_in =  [m/s, deg, N, N]
     */    
    table_in[0] = alphaVgamma[1];
    table_in[1] = alphaVgamma[0]*RAD2DEG;
    table_in[2] = Fbody[0];
    table_in[3] = Fbody[1];

    if (aero_verbose > 0) {
	printf(" + Input of inverse table:  ");
	for(i=0; i<4; i++) printf("%4.6f ", table_in[i]);
	printf("\n");
    }

    lu_lookup(forcetable, table_in, Volt_paddle);

    /* fixes deg2rad for paddle: */
    Volt_paddle[1] *= DEG2RAD;

    if (aero_verbose > 0) {
	printf(" + Output of inverse table:  ");
	for(i=0; i<2; i++) printf("%4.6f ", Volt_paddle[i]);
	printf("\n");
    }

    return 1;
}




