/*
 * trjfile.c - S-Function for reading trajectory files
 *
 * RMM 4/30/96
 *
 * Inputs:	none
 * Outputs:	from trajectory file
 * Inputargs:   filename (string)
 *
 */


#define S_FUNCTION_NAME trjfile
#include "simstruc.h"
#include "mex.h"
#include "falcon/traj.h"
#include <math.h>

extern char *dfspec(char *, char *);
/* #define TRJ_VERBOSE */

static TRAJ_DATA *loadtable(SimStruct *S)
{
    Matrix *fn;
    char trajfile[128], filename[1024];
    TRAJ_DATA *trjp;

    /* Grab the input argument and see if it is a string */
    fn = ssGetArg(S, 0);
    if (mxIsString(fn) == 0 || mxGetString(fn, trajfile, 127)) {
	mexPrintf("trjfile: filename parameter is not a valid string\n");
	return NULL;
    }

    /* Initialize the trajectory file information */
    if (trjp == NULL) { traj_free(trjp); trjp = NULL; }
    if (dfspec(trajfile, filename) == NULL || 
	(trjp = traj_load(filename)) == NULL) {
	fprintf(stderr, "trjfile: can't open %s\n", trajfile);
	return NULL;
    }
#   ifdef TRJ_VERBOSE
    fprintf(stderr, "trjfile: loaded %s\n", filename);
#   endif
    
    traj_reset(trjp);
#   ifdef TRJ_VERBOSE
    fprintf(stderr, "trjfile: reset trjp\n");
#   endif

    return trjp;
}

/* mdlInitializeSizes - initialize the sizes array */
static void mdlInitializeSizes(S)
SimStruct *S;
{
    TRAJ_DATA *trjp;

    if ((trjp = loadtable(S)) == NULL) return;

    ssSetNumContStates(    S, 0);      /* number of continuous states */
    ssSetNumDiscStates(    S, 0);      /* number of discrete states */
    ssSetNumInputs(        S, 0);      /* number of inputs */
    ssSetNumOutputs(       S, trjp->ncols);     /* number of outputs */
    ssSetDirectFeedThrough(S, 1);      /* direct feedthrough flag */
    ssSetNumSampleTimes(   S, 1);      /* number of sample times */
    ssSetNumInputArgs(     S, 1);      /* number of input arguments (parms) */
    ssSetNumRWork(         S, 0);      /* number real work vector elements */
    ssSetNumIWork(         S, 0);      /* number int work vector elements */
    ssSetNumPWork(         S, 1);      /* number ptr work vector elements */

    traj_free(trjp);
}

/* mdlInitializeSampleTimes - initialize the sample times array */
static void mdlInitializeSampleTimes(S)
SimStruct *S;
{
    int verbose = 1;
    static int firsttime = 1;
    /* Set things up to run as continuous time block */
    ssSetSampleTimeEvent(S, 0, 0.0);
    ssSetOffsetTimeEvent(S, 0, 0.0);
}

/* mdlInitializeConditions - initialize the states */
static void mdlInitializeConditions(x0, S)
double *x0;
SimStruct *S;
{
    /* Save the pointer to the trajectory table */
    ssSetPWorkValue(S, 0, loadtable(S));
}

/* mdlOutputs - compute the outputs */
static void mdlOutputs(y, x, u, S, tid)
double *y, *x, *u;
SimStruct *S;
int tid;
{
    double time = ssGetT(S);
    TRAJ_DATA *trjp = (TRAJ_DATA *) ssGetPWorkValue(S, 0);

    if (trjp == NULL) {
	fprintf(stderr, "trjfile: mdlOutputs called with trjp == NULL\n");
	return;
    }

    /* Look up the outputs from the table at the current time */
#   ifdef TRJ_VERBOSE
    fprintf(stderr, "trjfile: calling traj_read\n");
#   endif
    traj_read(trjp, y, time);
#   ifdef TRJ_VERBOSE
    fprintf(stderr, "trjfile: done reading data for time %g\n", time);
#   endif
}

/* mdlUpdate - perform action at major integration time step (not used) */
static void mdlUpdate(x, u, S, tid)
double *x, *u;
SimStruct *S;
int tid;
{
    /* Not used for this model */
}

/* mdlDerivatives - compute the derivatives */
static void mdlDerivatives(dx, x, u, S, tid)
double *dx, *x, *u;
SimStruct *S;
int tid;
{
}

/* mdlTerminate - called when the simulation is terminated */
static void mdlTerminate(S)
    SimStruct *S;
{
    TRAJ_DATA *trjp = (TRAJ_DATA *) ssGetPWorkValue(S, 0);

    /* Free up the trajectory file */
    if (trjp != NULL) traj_free(trjp);
    trjp = NULL;
}

/* Trailer information to set everything up for simulink usage */
#ifdef MATLAB_MEX_FILE    /* Is this file being compiled as a MEX-file? */
#include "simulink.c"      /* MEX-file interface mechanism */
#endif

#ifdef SIMLIB				/* set up for use with simlib */
#endif
